dict_of_parts = {
    "rpi3bp": "",
    "SLA-Battery": "",
    "XL4015": "",
    "BTS7960": "rear drive (2 motors) & steering drive (1 motor)",
    "470-mF": "",
    "Polyfuse": "",
    "TVS-diode": "",
    "330-ohm": "",
    "LED": "",
    "rpi-camera": "",
    "DC-gearboxed-motor-12V-120RPM": "",
}
